#
# spec file for package python-pyside
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name      pyside
%define libprefix  lib%{_name}
%define pyname     PySide
Name:           python-%{_name}
Version:        1.2.4
Release:        lp151.3.53
Summary:        PySide - python bindings for Qt
License:        LGPL-2.1+
Group:          Development/Languages/Python
Url:            http://qt-project.org/wiki/PySide
Source0:        https://pypi.python.org/packages/source/P/%{pyname}/%{pyname}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libqt4-devel >= 4.8
BuildRequires:  libshiboken-devel
BuildRequires:  libxslt-devel
BuildRequires:  phonon-devel
BuildRequires:  python-devel
BuildRequires:  python-pyside-shiboken
BuildRequires:  python-setuptools
# Built by python3-pyside
Requires:       python-pyside-common

%description
The PySide project provides LGPL-licensed Python bindings for the Qt
cross-platform application and UI framework. PySide Qt bindings allow both free
open source and proprietary software development and ultimately aim to support
all of the platforms as Qt itself.

%package devel
Summary:        PySide - python bindings for Qt
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       libqt4-devel
Requires:       libshiboken-devel

%description devel
The PySide project provides LGPL-licensed Python bindings for the Qt
cross-platform application and UI framework. PySide Qt bindings allow both free
open source and proprietary software development and ultimately aim to support
all of the platforms as Qt itself.

This package contains all the developer tools you need to create your own PyQt
applications.

%prep
%setup -q -n %{pyname}-%{version}

%build
python setup.py egg_info
cd sources/%{_name}
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DBUILD_TESTS=FALSE \
       -DQT_PHONON_INCLUDE_DIR=%{_includedir}/phonon
make %{?_smp_mflags}
ctest -R qtcore || true

%install
pushd sources/%{_name}/build
%makeinstall DESTDIR=%{buildroot}
# copy egg_info
cp -R %{_builddir}/%{pyname}-%{version}/%{_name}_package/%{pyname}.egg-info %{buildroot}%{py_sitedir}/%{pyname}-%{version}-py%{py_ver}.egg-info
%fdupes %{buildroot}
popd
# Part of python-pyside-common
rm -rf %{buildroot}%{_datadir}/%{pyname}/

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc sources/pyside/COPYING
%{_libdir}/%{libprefix}-python%{py_ver}.so.*
%{py_sitedir}/%{pyname}/
%{py_sitedir}/%{pyname}-%{version}-py%{py_ver}.egg-info/

%files devel
%defattr(-,root,root)
%{_includedir}/%{pyname}/
%{_libdir}/%{libprefix}-python%{py_ver}.so
%{_libdir}/cmake/*
%{_libdir}/pkgconfig/%{_name}.pc

%changelog
* Thu Dec 21 2017 fabian@ritter-vogt.de
- Require python-pyside-common for common files
* Sat Dec  2 2017 fabian@ritter-vogt.de
- Do not build with Qt4 WebKit:
  * Vade retro satana
* Thu Sep  8 2016 carlos@techbyte.ca
- Changed source from github to pypi.python.org
- Produced egg_info files
- Changed build type to release
* Tue Oct 27 2015 rpm@fthiessen.de
- Update to 1.2.4:
  * PYSIDE-164: Fix possible deadlock on signal connect/emit
  * New release of pyside-Shiboken
- Dropped empty doc package
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 1.2.2:
  * Register qt.conf in Qt resource system to override the Qt builtins
  * use file system encoding instead of assumed 'ascii'
  * Bug fixes
* Thu Dec 19 2013 p.drouand@gmail.com
- Specfile clean-up
- Remove obsolete conditionnal macros
- Remove depreciated %%{py_requires} macro
- Fix Group; standard is Devel/Languages/Python
* Wed Aug 28 2013 fisiu@opensuse.org
- Update to 1.2.1:
  * Bug fixes.
  * Fix build in C++11 mode.
- Update tarball url.
* Wed Aug 29 2012 toddrme2178@gmail.com
- Update to 1.1.2
  * bugfix release
* Fri Apr 20 2012 toddrme2178@gmail.com
- Update to version 1.1.1
  * Unified toolchain! No more GeneratorRunner and ApiExtractor,
    now you just need Shiboken to compile PySide.
  * Bug Fixes;
- Removed references to GeneratorRunner and ApiExtractor in spec
  file
* Thu Feb  9 2012 toddrme2178@gmail.com
- Add documentation
* Thu Feb  9 2012 toddrme2178@gmail.com
- Update to 1.1.0
- Spec file cleanups
* Sun Nov 20 2011 cgiboudeaux@gmx.com
- Update to 1.0.8
* Sat Jan 23 2010 cgoncalves@opensuse.org
- adapt specfile to also support Fedora and Mandriva
* Wed Jan  6 2010 cgoncalves@opensuse.org
- enable phonon support
* Mon Dec 28 2009 cgoncalves@opensuse.org
- fix build on <= openSUSE 11.1 against boost 1.36
* Mon Dec 28 2009 cgoncalves@opensuse.org
- update to version 0.2.3
* Sun Dec 13 2009 cgoncalves@opensuse.org
- update to version 0.2.2
* Mon Oct  5 2009 cgoncalves@opensuse.org
- update to version 0.2.1
* Thu Sep  3 2009 cgoncalves@opensuse.org
- update to version 0.2
* Mon Aug 31 2009 cgoncalves@opensuse.org
- pyside-link_against_lutil.patch: link tests against -lutil
* Sat Aug 29 2009 cgoncalves@opensuse.org
- pyside-build_boost_1.36.patch: allow building with boost>=1.36.0
  (needs more testing to make sure pyside will work okay though)
* Fri Aug 21 2009 cgoncalves@opensuse.org
- initial package (version 0.1.4.5)
